@@ -224,6 +224,14 @@ void DiagramScene::setMode(DiagramScene::Mode mode, bool m_abort)
     case MoveItem:
         enableAllItems(true);
         break;
+    case InsertItem:
+    case InsertDrawItem:
+    case InsertText:
+    case InsertUserElement:
+    case InsertElement:
+    case InsertLine:
+    case InsertSpline:
+        removePartnerItem();
     default:
         enableAllItems(false);
         break;
@@ -423,6 +431,9 @@ bool DiagramScene::isItemLocked(QGraphicsItem *item)
  */
 void DiagramScene::removePartnerItem()
 {
+    if(m_SelectedItem==nullptr){
+        return; // nothing to remove
+    }
     m_blockSelectionChanged=true;
     this->removeItem(m_SelectedItem);
     delete m_SelectedItem;
@@ -873,6 +884,7 @@ void DiagramScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
             // copy
             copiedItems=copyItems(myList);
             myMode=CopyingItem;
+            clearSelection();
         }
         if(middleButton){
             // switch toolbar !!
@@ -1301,8 +1313,9 @@ QGraphicsItem* DiagramScene::copy(QGraphicsItem* item)
     }
 }
 
-void DiagramScene::clear()
+void DiagramScene::clearScene()
 {
+    removePartnerItem();
     foreach(QGraphicsItem *item,items()){
         if(item!=&myCursor)
         {
@@ -1579,11 +1592,11 @@ void DiagramScene::restoreSnapshot(int pos)
         // at m_undoPos
         if(m_undoPos>0){
             --m_undoPos;
-            clear();
+            clearScene();
             read_in_json(m_snapshots.at(m_undoPos));
         }
     }else{
-        clear();
+        clearScene();
         read_in_json(m_snapshots.at(pos));
         m_undoPos=pos;
     }
@@ -1707,6 +1720,7 @@ QJsonDocument DiagramScene::create_json_save(bool selectedItemsOnly)
     QJsonArray array;
     QList<QGraphicsItem*> lst=selectedItemsOnly ? selectedItems() : items();
     foreach(QGraphicsItem* item, lst){
+        if(item==m_SelectedItem) continue; // don't snapshot partner item
         if(item->parentItem()) continue;
         addElementToJSON(item,array);
     }
